#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################

MODULE="LuUMTS_CS"
RELEASE="6.0.9.3.10"    

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}/${MODULE}"
utilDir="${FLEXPM_HOME}/patches/${RELEASE}/utils"
RP=$(echo $RELEASE|sed 's/\.//g')
TarDir=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

mkdir -p ${SourceDir}/Backup
TS=`date +"%Y%m%d.%H%M%S"`
BACKUP_DIR=${SourceDir}/Backup/${TS}


########################################################
# Check environment settings
echo "Checking environment....."

if ! [[ -d ${FLEXPM_HOME} ]]; then
  echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
  exit 3;
fi

if ! [[ -d ${FLEXPM_BASE} ]]; then
  echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
  exit 3;
fi

if [ -z ${DB_CONNECT} ]; then
  echo "Env variable DB_CONNECT must be set to appropriate database connection values."
  exit 3;
fi

if ! [[ -d ${LuUMTS_CS_HOME} ]]; then
  echo "Env variable LuUMTS_CS_HOME must be set to appropriate dir before installation."
  exit 3;
fi

#######################################################
# Installing updated files ...
#######################################################
date +"+ Installing Patch ${MODULE} ${RELEASE} at %T, %D ..."

echo "+ Backing up original files and installing new files..."

mkdir -p ${BACKUP_DIR}
${utilDir}/untar.pl ${SourceDir} ${TarDir} ${FLEXPM_BASE} ${BACKUP_DIR}
ret=$?

if [ $ret != 0 ]; then
  echo "+++ Error in untar.pl"
  exit 2
fi


#######################################################
# Perform custom actions ...
#######################################################

cd $LuUMTS_CS_HOME/peik/xml

touch parser.err
chmod 777 parser.err
 
# Perform a dict_update to load the latest data dictionary into the database.
echo "+ Updating the data dictionary ..."
cd ${LuUMTS_CS_HOME}/peik
make dict_update
ret=$?

if [ $ret != 0 ]; then
  echo "+++ Error encountered during the data dictionary update."
  echo "+++ Please consult with IBM support for advice"
  exit 3
fi

echo "### completed dict_update ###"

#recompile all invalid objects (except for views...):
echo "+ recompiling any invalid object(s)..."
chmod u+x ${utilDir}/recompile_schema.sh
${utilDir}/recompile_schema.sh

#and we recompile for invalid views here...
echo "+ recompiling any invalid view(s)..."
chmod u+x ${utilDir}/recompile_view.sh
${utilDir}/recompile_view.sh
echo " recompilation done." 

### update CallServer loader
cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/1.3/LuUMTS_CS_loader/CallServer0302_pm/config
make dict_update


#######################################################
# Patching is complete ...
#######################################################
date +"+ ${MODULE} ${RELEASE} upgrade is completed at %T, %D"
echo  ""

