#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################

MODULE="LuUTRAN"
RELEASE="6.0.9.3.10"    

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}/${MODULE}"
utilDir="${FLEXPM_HOME}/patches/${RELEASE}/utils"
RP=$(echo $RELEASE|sed 's/\.//g')
TarDir=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

mkdir -p ${SourceDir}/Backup
TS=`date +"%Y%m%d.%H%M%S"`
BACKUP_DIR=${SourceDir}/Backup/${TS}


########################################################
# Check environment settings
echo "Checking environment....."

if ! [[ -d ${FLEXPM_HOME} ]]; then
  echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
  exit 3;
fi

if ! [[ -d ${FLEXPM_BASE} ]]; then
  echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
  exit 3;
fi

if [ -z ${DB_CONNECT} ]; then
  echo "Env variable DB_CONNECT must be set to appropriate database connection values."
  exit 3;
fi

if ! [[ -d ${LuUTRAN_HOME} ]]; then
  echo "Env variable LuUTRAN_HOME must be set to appropriate dir before installation."
  exit 3;
fi

#######################################################
# Installing updated files ...
#######################################################
date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

echo "+ Backing up original files and installing new files..."

mkdir -p ${BACKUP_DIR}
${utilDir}/untar.pl $SourceDir $TarDir $FLEXPM_BASE $BACKUP_DIR
ret=$?

if [ $ret != 0 ]; then
  echo "+++ Error in untar.pl"
  exit 2
fi


#######################################################
# Perform custom actions ...
#######################################################

# Rebuild the data dictionary
cd ${LuUTRAN_HOME}/peik
make dict_update
ret=$?
if [ $ret != 0 ]; then
  echo "+++ Error while performing dict_update!"
  exit 2
fi

#recompile all invalid objects (except for views...):
echo "+ recompiling any invalid object(s)..."
chmod u+x ${utilDir}/recompile_schema.sh
${utilDir}/recompile_schema.sh

#and we recompile for invalid views here...
echo "+ recompiling any invalid view(s)..."
chmod u+x ${utilDir}/recompile_view.sh
${utilDir}/recompile_view.sh
echo " recompilation done."

# Update the RNCIN loader for additional entity and counter to load 
cd ${LuUTRAN_HOME}/vendor/Lucent/UTRAN/1.3/LuUTRAN_loader/RNCIN/
make clean 
make all
ret=$?
if [ $ret != 0 ]; then
  echo "+++ Error while performing RNC I-Node reconfiguration!"
  exit 2
fi 


#######################################################
# Patching is complete ...
#######################################################
date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
echo 

